@@ -15,8 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-// $Id: phrasebook.cpp,v 1.4 2003/03/07 10:07:21 gunnar Exp $
-
 #include <qprinter.h>
 #include <qpainter.h>
 #include <qfile.h>
@@ -31,6 +29,8 @@
 #include <ktempfile.h>
 #include <kio/netaccess.h>
 #include <kfiledialog.h>
+#include <kmessagebox.h>
+#include <kglobalsettings.h>
 
 #include "phrasebookparser.h"
 #include "phrasebook.h"
@@ -38,33 +38,33 @@
 Phrase::Phrase() {
    this->phrase = "";
    this->shortcut = "";
-};
+}
 
 Phrase::Phrase (const QString &phrase) {
    this->phrase = phrase;
    this->shortcut = "";
-};
+}
 
 Phrase::Phrase (const QString &phrase, const QString &shortcut) {
    this->phrase = phrase;
    this->shortcut = shortcut;
-};
+}
 
 QString Phrase::getPhrase() const {
    return phrase;
-};
+}
 
 QString Phrase::getShortcut() const {
    return shortcut;
-};
+}
 
 void Phrase::setPhrase (const QString &phrase) {
    this->phrase = phrase;
-};
+}
 
 void Phrase::setShortcut (const QString &shortcut) {
    this->shortcut = shortcut;
-};
+}
 
 // ***************************************************************************
 
@@ -102,7 +102,7 @@ void PhraseBook::print(KPrinter *pPrinter) {
    int x = size.x();
    int y = size.y();
    int w = size.width();
-   printpainter.setFont (QFont ("Helvetica", 12));
+   printpainter.setFont (QFont (KGlobalSettings::generalFont().family(), 12));
    QFontMetrics metrics = printpainter.fontMetrics();
 
    PhraseBookEntryList::iterator it;
@@ -228,7 +228,7 @@ bool PhraseBook::save (const KURL &url, bool asPhrasebook) {
       QFile file(url.path());
       if(!file.open(IO_WriteOnly))
          return false;
-      
+
       QTextStream stream(&file);
       save (stream, asPhrasebook);
       file.close();
@@ -250,7 +250,7 @@ bool PhraseBook::save (const KURL &url, bool asPhrasebook) {
 }
 
 int PhraseBook::save (QWidget *parent, const QString &title, KURL &url, bool phrasebookFirst) {
-   // KFileDialog::getSaveURL(...) is not usefull here as we need
+   // KFileDialog::getSaveURL(...) is not useful here as we need
    // to know the requested file type.
 
    QString filters;
@@ -263,25 +263,65 @@ int PhraseBook::save (QWidget *parent, const QString &title, KURL &url, bool phr
    fdlg.setCaption(title);
    fdlg.setOperationMode( KFileDialog::Saving );
 
-   fdlg.exec();
+   if (fdlg.exec() != QDialog::Accepted) {
+     return 0;
+   }
+
    url = fdlg.selectedURL();
 
-   if(!url.isEmpty()) {
-      bool result;
-      if (fdlg.currentFilter() == "*.phrasebook")
-         result = save (url, true);
-      else if (fdlg.currentFilter() == "*.txt")
-         result = save (url, false);
-      else // file format "All files" requested, so decide by extension
-         result = save (url);
+   if (url.isEmpty() || url.isMalformed()) {
+      return -1;
+   }
 
-      if (result)
-         return 1;
-      else {
-         return -1;
+   if (KIO::NetAccess::exists(url)) {
+      if (KMessageBox::warningContinueCancel(0,QString("<qt>%1</qt>").arg(i18n("The file %1 already exists. "
+                                                       "Do you want to overwrite it?").arg(url.url())),i18n("File Exists"),i18n("&Overwrite"))==KMessageBox::Cancel) {
+         return 0;
       }
    }
-   return 0;
+
+   bool result;
+   if (fdlg.currentFilter() == "*.phrasebook") {
+      if (url.fileName (false).contains('.') == 0) {
+         url.setFileName (url.fileName(false) + ".phrasebook");
+      }
+      else if (url.fileName (false).right (11).contains (".phrasebook", false) == 0) {
+         int filetype = KMessageBox::questionYesNoCancel (0,QString("<qt>%1</qt>").arg(i18n("Your chosen filename <i>%1</i> has a different extension than <i>.phrasebook</i>. "
+                                                           "Do you wish to add <i>.phrasebook</i> to the filename?").arg(url.filename())),i18n("File Extension"));
+         if (filetype == KMessageBox::Cancel) {
+            return 0;
+         }
+         if (filetype == KMessageBox::Yes) {
+            url.setFileName (url.fileName(false) + ".phrasebook");
+         }
+      }
+      result = save (url, true);
+   }
+   else if (fdlg.currentFilter() == "*.txt") {
+      if (url.fileName (false).right (11).contains (".phrasebook", false) == 0) {
+         result = save (url, false);
+      }
+      else {
+         int filetype = KMessageBox::questionYesNoCancel (0,QString("<qt>%1</qt>").arg(i18n("Your chosen filename <i>%1</i> has the extension <i>.phrasebook</i>."
+                                                           "Do you wish to save in phrasebook format?").arg(url.filename())),i18n("File Extension"),i18n("As Phrasebook"),i18n("As Plain Text"));
+         if (filetype == KMessageBox::Cancel) {
+            return 0;
+         }
+         if (filetype == KMessageBox::Yes) {
+            result = save (url, true);
+         }
+         else {
+            result = save (url, false);
+         }
+      }
+   }
+   else // file format "All files" requested, so decide by extension
+      result = save (url);
+
+   if (result)
+      return 1;
+   else
+      return -1;
 }
 
 bool PhraseBook::open (const KURL &url) {
@@ -470,56 +510,3 @@ bool PhraseBookDrag::decode (const QMimeSource *e, PhraseBook *book) {
 }
 
 #include "phrasebook.moc"
-
-/*
- * $Log: phrasebook.cpp,v $
- * Revision 1.4  2003/03/07 10:07:21  gunnar
- * Fixed several bugs that I found when using valgrind
- *
- * Revision 1.3  2003/02/02 21:05:51  mlaurent
- * Fix include/header
- * Add some const
- *
- * Revision 1.2  2003/01/18 07:29:12  binner
- * CVS_SILENT i18n style guide fixes
- *
- * Revision 1.1  2003/01/17 23:09:36  gunnar
- * Imported KMouth into kdeaccessibility
- *
- * Revision 1.6  2003/01/12 21:52:50  gunnar
- * Printing improved.
- *
- * Revision 1.5  2003/01/12 20:26:02  gunnar
- * Printing phrase book added
- *
- * Revision 1.4  2003/01/12 11:37:05  gunnar
- * Improved format list of file selectors / several small changes
- *
- * Revision 1.3  2002/12/06 08:55:05  gunnar
- * Improved the algorithm for creating the initial phrasebook
- *
- * Revision 1.2  2002/12/04 16:22:02  gunnar
- * Include *.moc files
- *
- * Revision 1.1  2002/11/11 21:25:44  gunnar
- * Moved the parts concerning phrase books into a static library
- *
- * Revision 1.6  2002/10/29 20:29:22  gunnar
- * Small changes
- *
- * Revision 1.5  2002/10/29 18:11:17  gunnar
- * Implemented opening and saving of a standard phrasebook
- *
- * Revision 1.4  2002/10/28 16:58:34  gunnar
- * Import and export of phrase books implemented
- *
- * Revision 1.3  2002/10/23 22:19:30  gunnar
- * Cut, copy and paste features of the phrase book edit dialog improved
- *
- * Revision 1.2  2002/10/22 20:10:29  gunnar
- * Cut and copy of phrase book entries implemented
- *
- * Revision 1.1  2002/10/21 16:13:30  gunnar
- * phrase book format implemented
- *
- */
